# Changelog

## 0.8.0 (2026-03-20)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/fragment-dev/fragment-py/compare/v0.7.0...v0.8.0)

### Features

* **api:** update SDK from prod (53b45d453f41b1366df505c650638a5bc0772a9b) ([8f028ed](https://github.com/fragment-dev/fragment-py/commit/8f028ed1c3903c9e0c6666e025469a3d22964f04))
* **api:** update SDK from prod (7939c0e32c1f9c777bb9a7ec9365aa0a4fd7a926) ([6b465f3](https://github.com/fragment-dev/fragment-py/commit/6b465f3f923c4435676b6ac89ca5501ff3db31c2))

## 0.7.0 (2026-03-19)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/fragment-dev/fragment-py/compare/v0.6.0...v0.7.0)

### Features

* **api:** update SDK from prod (05bf1df4cca252f534c40121ea46dfa01d2f376d) ([db5669a](https://github.com/fragment-dev/fragment-py/commit/db5669a9ff9a5be7fb6649459e46fcb25d8de902))
* **api:** update SDK from prod (125ed953796b4ee57adf8ed0e798e76381593713) ([d31c65c](https://github.com/fragment-dev/fragment-py/commit/d31c65c179e82675872c8304c8501115003b8778))
* **api:** update SDK from prod (1b76bfcb7da068f20abd5c64ea192f91ab0d22e3) ([e2135e2](https://github.com/fragment-dev/fragment-py/commit/e2135e2731be79eeb1c7f5f1c2fe3384cb64067f))
* **api:** update SDK from prod (1c845e9cebd1bd4a20412a587d5da0b2b2297932) ([51e872a](https://github.com/fragment-dev/fragment-py/commit/51e872a22172cd0370b48bf73c02d63543a6855c))
* **api:** update SDK from prod (1ece54d1e3c816fc1a22c91c85ec64ff88cb2281) ([3a3c9e5](https://github.com/fragment-dev/fragment-py/commit/3a3c9e5d0c08fbcbc6f317929aee3b53480e618c))
* **api:** update SDK from prod (220e8ac65390cfb3ecb02c0782f6fdc487330eb6) ([0662cac](https://github.com/fragment-dev/fragment-py/commit/0662cacee6b8cdb1cfd7b4db9eac7bee515161ba))
* **api:** update SDK from prod (28557dc7a7816a62fb63945cd9d2b04ac2cf0b78) ([e2403ec](https://github.com/fragment-dev/fragment-py/commit/e2403ec02a7a7d9fcdedccd24d47c53122c96383))
* **api:** update SDK from prod (5e74af7746e480f849a4ce975e055c18e363ae3c) ([734309f](https://github.com/fragment-dev/fragment-py/commit/734309faefb6c6fc82dd786e6e2155f93978fee8))
* **api:** update SDK from prod (65cfb437aa5042cd51b31d52af3960c3d7821658) ([2f550dc](https://github.com/fragment-dev/fragment-py/commit/2f550dc86b9e68ec9698e213653cc0da62b854a4))
* **api:** update SDK from prod (6ac170e37ed0ad105f0c6d0c38aa504a78b0be06) ([f901d01](https://github.com/fragment-dev/fragment-py/commit/f901d01266ee04da18596801912f41a3895e356f))
* **api:** update SDK from prod (77121392df161dccc09b4aa751c8b0331da2abfa) ([459bfe5](https://github.com/fragment-dev/fragment-py/commit/459bfe5ad6f36d6f63c9c716838bb4c8d75bbdd4))
* **api:** update SDK from prod (85a20f53715da2d6cac9bd99aed04dc0d926085a) ([6028591](https://github.com/fragment-dev/fragment-py/commit/602859161e4aff70185a9e35cb1550f33c1c30ea))
* **api:** update SDK from prod (9924c80a76e93623f97868eed66329e7b59f86a1) ([c2bc590](https://github.com/fragment-dev/fragment-py/commit/c2bc590c684393dfad2d213ec89c798bd70adebb))
* **api:** update SDK from prod (9c162134866788931d5ab6bc81c47ca2bbf4140f) ([fdaa2ee](https://github.com/fragment-dev/fragment-py/commit/fdaa2eedfd424603b0f701e021c6b55cedf9d7fa))
* **api:** update SDK from prod (b30e63af1a25df1c73581c71d53ebd4e73d9cbfc) ([37ee421](https://github.com/fragment-dev/fragment-py/commit/37ee4217eb838397af533d238a5498b6db65223b))
* **api:** update SDK from prod (ce1a36c617a4b73d16f930c0eedd9168e7c180fe) ([999b2af](https://github.com/fragment-dev/fragment-py/commit/999b2afa0c2f1e6aeb5ccce504f9fa144896dc57))
* **api:** update SDK from prod (d4499f29205b1835d41b782c54dad258b705f2c3) ([3f7a555](https://github.com/fragment-dev/fragment-py/commit/3f7a5554cf1afc6b4b3bf431377a5db5f1a179b7))
* **api:** update SDK from prod (ddaba31becc06a3281d77f308b37e78a26d8ec41) ([9d45f5f](https://github.com/fragment-dev/fragment-py/commit/9d45f5ff466bef577c47106448f1ff1402b1bab2))


### Bug Fixes

* **deps:** bump minimum typing-extensions version ([8060146](https://github.com/fragment-dev/fragment-py/commit/8060146f88308b19660568bb98e37293007dcf61))
* **pydantic:** do not pass `by_alias` unless set ([a8ce80a](https://github.com/fragment-dev/fragment-py/commit/a8ce80a6af94406095bb4703b7995d044767780f))
* sanitize endpoint path params ([e5f8ca3](https://github.com/fragment-dev/fragment-py/commit/e5f8ca35e8d5d8d1c99f829b706a2051a3c3f059))
* **tests:** correct setup of OAuth 2 Client Credentials tests ([ea5906b](https://github.com/fragment-dev/fragment-py/commit/ea5906b39a1e18045d3732af981f191ccf4d7428))


### Chores

* **ci:** bump uv version ([616ff04](https://github.com/fragment-dev/fragment-py/commit/616ff04fc54466d66c8749c13bd0fcf1d9ca0ab2))
* **ci:** skip uploading artifacts on stainless-internal branches ([8843bee](https://github.com/fragment-dev/fragment-py/commit/8843bee1a042db28d04bf94b2390d55a7a5ce057))
* **internal:** add request options to SSE classes ([600df5c](https://github.com/fragment-dev/fragment-py/commit/600df5cec3cb697138162007caba79538f50a71a))
* **internal:** codegen related update ([39db6c9](https://github.com/fragment-dev/fragment-py/commit/39db6c9a7d4b71860908bffdb684684ce540da6c))
* **internal:** make `test_proxy_environment_variables` more resilient ([096a00d](https://github.com/fragment-dev/fragment-py/commit/096a00db68f11b5c7b77f075a9bde694cd4987e9))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([b97fb0d](https://github.com/fragment-dev/fragment-py/commit/b97fb0deb07e54b46fea6c9a43be0e97f873388e))
* **internal:** tweak CI branches ([2e2c07f](https://github.com/fragment-dev/fragment-py/commit/2e2c07fff6706adac1469de385dd8cb0e6fe3c79))

## 0.6.0 (2026-02-20)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/fragment-dev/fragment-py/compare/v0.5.0...v0.6.0)

### Features

* **api:** update SDK from prod (8d737b90aab6f5a1025d4eef6d9d25694140b220) ([af51366](https://github.com/fragment-dev/fragment-py/commit/af51366be4c80936e708807d63b67f55b14b5023))

## 0.5.0 (2026-02-20)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/fragment-dev/fragment-py/compare/v0.4.0...v0.5.0)

### Features

* **api:** update SDK from prod (02129bd3c8d07cabd99ba1849b1ce21f4a73c752) ([972d94a](https://github.com/fragment-dev/fragment-py/commit/972d94af4473fb8b59d1a7f27ab0ed8d55183464))
* **api:** update SDK from prod (041a7148982b6eb68cdc510d139846bb9acf48f9) ([0e05896](https://github.com/fragment-dev/fragment-py/commit/0e058968554e5af724f0e208200cf4c419fe973a))
* **api:** update SDK from prod (bafb7c5c7699ca57dac84e441c66bd40b1d9ba93) ([2eb8cb3](https://github.com/fragment-dev/fragment-py/commit/2eb8cb3f6fb25fdd07d1470f2890dcf47a7fa004))
* **api:** update SDK from prod (dc1f471db694468a6bfd4a3b15c6af34a19fbc3e) ([8f139d0](https://github.com/fragment-dev/fragment-py/commit/8f139d0e8469e21372539338d464ce7c685ec37c))
* **api:** update SDK from prod (f13cfc23ac55aaae9d293cb5cbb431e4fe2e98a4) ([cfbf9f9](https://github.com/fragment-dev/fragment-py/commit/cfbf9f9adb4186a1f76eac09f6843ba05ea29c3c))


### Chores

* **internal:** remove mock server code ([27c6f12](https://github.com/fragment-dev/fragment-py/commit/27c6f128118ba36cd3959eeb6be018f6948e96eb))
* update mock server docs ([78dccf4](https://github.com/fragment-dev/fragment-py/commit/78dccf437bc05484bb55334e0d10f191b5408302))

## 0.4.0 (2026-02-16)

Full Changelog: [v0.3.2...v0.4.0](https://github.com/fragment-dev/fragment-py/compare/v0.3.2...v0.4.0)

### Features

* **api:** manual updates ([72bcc66](https://github.com/fragment-dev/fragment-py/commit/72bcc6626908a38f2156928796cb1bc8875e47e3))

## 0.3.2 (2026-02-13)

Full Changelog: [v0.3.1...v0.3.2](https://github.com/fragment-dev/fragment-py/compare/v0.3.1...v0.3.2)

### Chores

* format all `api.md` files ([41b3e60](https://github.com/fragment-dev/fragment-py/commit/41b3e6015cb99db9be7aa990a5e6c63ab532f2e0))
* **internal:** fix lint error on Python 3.14 ([4e8ff95](https://github.com/fragment-dev/fragment-py/commit/4e8ff95efc79d174acafd76e5cee4ff139530be1))

## 0.3.1 (2026-02-10)

Full Changelog: [v0.3.0...v0.3.1](https://github.com/fragment-dev/fragment-py/compare/v0.3.0...v0.3.1)

### Chores

* **internal:** bump dependencies ([90b74c2](https://github.com/fragment-dev/fragment-py/commit/90b74c2b42c1edac4bb1a8aa693594e7e42d51e3))

## 0.3.0 (2026-02-05)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/fragment-dev/fragment-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** breaking API changes ([4a6e374](https://github.com/fragment-dev/fragment-py/commit/4a6e3749f2d98bddf436e07ba849d2e2c7073dc6))

## 0.2.0 (2026-02-03)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/fragment-dev/fragment-py/compare/v0.1.0...v0.2.0)

### Features

* **api:** OpenAPI spec update via Stainless ([#4](https://github.com/fragment-dev/fragment-py/issues/4)) ([6dd1723](https://github.com/fragment-dev/fragment-py/commit/6dd17231504a28f7a5008d5c54c7eabff8910a16))

## 0.1.0 (2026-02-02)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/fragment-dev/fragment-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([6ed6c9f](https://github.com/fragment-dev/fragment-py/commit/6ed6c9fb6f1c6e4a0d90661a2f45086d4693ecd3))
* **api:** api update ([a36f59b](https://github.com/fragment-dev/fragment-py/commit/a36f59b2fad84a8a62431018e062c911b9f6284f))


### Bug Fixes

* **client/oauth:** send grant_type in the right location ([da1f6db](https://github.com/fragment-dev/fragment-py/commit/da1f6db06f11bf666fa02a2fc01535b6e628f2ce))


### Chores

* configure new SDK language ([32d4975](https://github.com/fragment-dev/fragment-py/commit/32d4975e21ad1144cdc047e8bb7eb8c7a202a239))
* update SDK settings ([5b46542](https://github.com/fragment-dev/fragment-py/commit/5b46542034f3fef7df86b372d20ca5bd68cc3613))
* update SDK settings ([dceb203](https://github.com/fragment-dev/fragment-py/commit/dceb2030cfd3b47037ae0365fffa4d71ba418919))
* update SDK settings ([931490f](https://github.com/fragment-dev/fragment-py/commit/931490fb3310f3348befc5a6df33ae0813149e16))
* update SDK settings ([6a2ba6c](https://github.com/fragment-dev/fragment-py/commit/6a2ba6c1b775d248c3cb1743d0d2de34885eae5c))
* update SDK settings ([b141e78](https://github.com/fragment-dev/fragment-py/commit/b141e789dbae9df530ea965d4473cc67b400a4e1))
* update SDK settings ([0ecf9e6](https://github.com/fragment-dev/fragment-py/commit/0ecf9e650956e9f73b80a899ce2b51811445ed20))
* update SDK settings ([399dc85](https://github.com/fragment-dev/fragment-py/commit/399dc851eeac705826d88c49a4bece529011c91b))
